@@ -3,7 +3,7 @@ import wave
 
 
 def get_wave_duration(wave_filepath):
-    with contextlib.closing(wave.open(wave_filepath, 'r')) as f:
+    with contextlib.closing(wave.open(str(wave_filepath), 'r')) as f:
         frames = f.getnframes()
         rate = f.getframerate()
         duration = frames / float(rate)
