@@ -1,4 +1,5 @@
 import functools
+from numbers import Integral
 
 
 # RGB order
@@ -46,7 +47,7 @@ def voc_colormap(nlabels, order='rgb'):
 
 
 def cmap(value):
-    if isinstance(value, int):
+    if isinstance(value, Integral):
         return _voc_colormap(value)
     if isinstance(value, str):
         return flat_colors[value]
